<?php
/**
 * The Midas script to show a summary of campaigns.
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: midas/campaigns.php,v 1.24 2005/01/03 14:35:14 jan Exp $
 *
 * @author Marko Djukic <marko@oblo.com>
 * @version $Revision: 1.24 $
 * @package Midas
 */

@define('MIDAS_BASE', dirname(__FILE__));
require_once MIDAS_BASE . '/lib/base.php';

/* Only admin should be using this. */
if (!Auth::isAdmin('midas:admin', PERMS_SHOW)) {
    $notification->push(_("You are not authorised for this action."), 'horde.warning');
    Horde::authenticationFailureRedirect();
}

/* How about starting off with a prefs value rather than 0? */
if (!isset($_SESSION['midas_show_active'])) {
    $_SESSION['midas_show_active'] = 0;
}
if (!isset($_SESSION['midas_show_new'])) {
    $_SESSION['midas_show_new'] = 0;
}
if (!isset($_SESSION['midas_show_old'])) {
    $_SESSION['midas_show_old'] = 0;
}

$filter = Util::getFormData('filter');
switch ($filter) {
case 'active':
    $_SESSION['midas_show_active'] = $_SESSION['midas_show_active'] ? 0 : 1;
    break;

case 'new':
    $_SESSION['midas_show_new'] = $_SESSION['midas_show_new'] ? 0 : 1;
    break;

case 'old':
    $_SESSION['midas_show_old'] = $_SESSION['midas_show_old'] ? 0 : 1;
}

$stats_total = $campaigns->getCampaignStats();
if (is_a($stats_total, 'PEAR_Error')) {
    Horde::fatal($stats_total, __FILE__, __LINE__);
}

$stats_active = $campaigns->getCampaignStats('active');
if (is_a($stats_active, 'PEAR_Error')) {
    Horde::fatal($stats_active, __FILE__, __LINE__);
}

$stats_new = $campaigns->getCampaignStats('new');
if (is_a($stats_new, 'PEAR_Error')) {
    Horde::fatal($stats_new, __FILE__, __LINE__);
}

$stats_old = $campaigns->getCampaignStats('old');
if (is_a($stats_old, 'PEAR_Error')) {
    Horde::fatal($stats_old, __FILE__, __LINE__);
}

if ($stats_active['campaigns'] > 0 && Auth::isAdmin('midas:admin', PERMS_READ)) {
    $hideshow_active = ($_SESSION['midas_show_active'] == '1') ? _("hide") : _("show");
    $hideshow_active = Horde::link(Util::addParameter(Horde::applicationUrl('campaigns.php', true), 'filter', 'active')) . $hideshow_active . '</a>';
} else {
    $_SESSION['midas_show_active'] = 0;
    $hideshow_active = '';
}
if ($stats_new['campaigns'] > 0 && Auth::isAdmin('midas:admin', PERMS_READ)) {
    $hideshow_new = ($_SESSION['midas_show_new'] == '1') ? _("hide") : _("show");
    $hideshow_new = Horde::link(Util::addParameter(Horde::applicationUrl('campaigns.php', true), 'filter', 'new')) . $hideshow_new . '</a>';
} else {
    $_SESSION['midas_show_new'] = 0;
    $hideshow_new = '';
}
if ($stats_old['campaigns'] > 0 && Auth::isAdmin('midas:admin', PERMS_READ)) {
    $hideshow_old = ($_SESSION['midas_show_old'] == '1') ? _("hide") : _("show");
    $hideshow_old = Horde::link(Util::addParameter(Horde::applicationUrl('campaigns.php', true), 'filter', 'old')) . $hideshow_old . '</a>';
} else {
    $_SESSION['midas_show_old'] = 0;
    $hideshow_old = '';
}

require MIDAS_TEMPLATES . '/common-header.inc';
require MIDAS_TEMPLATES . '/menu.inc';
$notification->notify(array('listeners' => 'status'));
require MIDAS_TEMPLATES . '/campaigns/summary.inc';
if (Auth::isAdmin('midas:admin', PERMS_READ)) {
    $campaign_list = array();
    if ($_SESSION['midas_show_active'] == '1') {
        $campaign_list = array_merge($campaign_list, array(array('tab_class' => 'activetitle', 'tab_title' => _("Active campaigns"))), $campaigns->getCampaignList('active'));
    }
    if ($_SESSION['midas_show_new'] == '1') {
        $campaign_list = array_merge($campaign_list, array(array('tab_class' => 'newtitle', 'tab_title' => _("Upcoming campaigns"))), $campaigns->getCampaignList('new'));
    }
    if ($_SESSION['midas_show_old'] == '1') {
        $campaign_list = array_merge($campaign_list, array(array('tab_class' => 'oldtitle', 'tab_title' => _("Closed campaigns"))), $campaigns->getCampaignList('old'));
    }
    require MIDAS_TEMPLATES . '/campaigns/list.inc';
}
require $registry->get('templates', 'horde') . '/common-footer.inc';
