<?php
/**
 * The Midas script to delete clients.
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: midas/clients/delete.php,v 1.15 2005/01/03 14:35:15 jan Exp $
 *
 * @author Marko Djukic <marko@oblo.com>
 * @version $Revision: 1.15 $
 * @package Midas
 */

@define('MIDAS_BASE', dirname(__FILE__) . '/..');
require_once MIDAS_BASE . '/lib/base.php';
require_once 'Horde/Form.php';
require_once 'Horde/Form/Renderer.php';
require_once 'Horde/Variables.php';

/* Only admin should be using this. */
if (!Auth::isAdmin('midas:admin', PERMS_SHOW)) {
    $notification->push(_("You are not authorised for this action."), 'horde.warning');
    Horde::authenticationFailureRedirect();
}

/* Get some variables. */
$view = Util::getFormData('view');
$vars = &Variables::getDefaultVariables();
$client_id = $vars->get('client_id');
$form_submit = $vars->get('submitbutton');

/* Get client. */
$client = $clients->getClient($client_id);
if (is_a($client, 'PEAR_Error')) {
    $notification->push(sprintf(_("Can not delete client. %s"), $client->getMessage()), 'horde.error');
    $url = Horde::applicationUrl('clients/index.php', true);
    header('Location: ' . $url);
    exit;
}

$vars = &new Variables($client);

/* Set up title. */
$title = sprintf(_("Delete Client '%s'"), $client['client_name']);

/* Set up the form object. */
$form = &Horde_Form::singleton('', $vars, $title);

/* Set up the form. */
$form->setButtons(array(_("Delete"), _("Do not delete")));
$form->addHidden('', 'client_id', 'int', false);
$form->addVariable(_("Do you really wish to delete this client and all the relative campaigns?"), '', 'description', false);

if ($form_submit == _("Delete")) {
    if ($form->validate($vars)) {
        $form->getInfo($vars, $info);
        $delete = $clients->deleteClient($info['client_id']);
        if (is_a($delete, 'PEAR_Error')) {
            $notification->push(sprintf(_("Could not delete client. %s"), $delete->message), 'horde.error');
        } else {
            $notification->push(_("Client deleted."), 'horde.success');
            $url = Horde::applicationUrl('clients/index.php', true);
            header('Location: ' . $url);
            exit;
        }
    }
} elseif (!empty($form_submit)) {
    $notification->push(_("Client has not been deleted."), 'horde.message');
    $url = Horde::applicationUrl('clients/index.php', true);
    header('Location: ' . $url);
    exit;
}


/* Output the page. */
require MIDAS_TEMPLATES . '/common-header.inc';
require MIDAS_TEMPLATES . '/menu.inc';
$notification->notify(array('listeners' => 'status'));

/* Render the form. */
$renderer = &new Horde_Form_Renderer();
$form->renderActive($renderer, $vars, 'delete.php', 'post');

require $registry->get('templates', 'horde') . '/common-footer.inc';
