<?php
/**
 * The Midas script to edit clients.
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: midas/clients/edit.php,v 1.18 2005/01/03 14:35:15 jan Exp $
 *
 * @author Marko Djukic <marko@oblo.com>
 * @version $Revision: 1.18 $
 * @package Midas
 */

@define('MIDAS_BASE', dirname(__FILE__) . '/..');
require_once MIDAS_BASE . '/lib/base.php';
require_once 'Horde/Form.php';
require_once 'Horde/Form/Renderer.php';
require_once 'Horde/Variables.php';

/* Only admin should be using this. */
if (!Auth::isAdmin('midas:admin', PERMS_SHOW)) {
    $notification->push(_("You are not authorised for this action."), 'horde.warning');
    Horde::authenticationFailureRedirect();
}

/* Get some variables. */
$view = Util::getFormData('view');
$vars = &Variables::getDefaultVariables();
$client_id = $vars->get('client_id');

/* Check if a client is being edited. */
if ($client_id) {
    $vars = &new Variables($clients->getClient($client_id));
    if ($view) {
        $title = _("Client Details");
    } else {
        $title = _("Edit Client");
    }
} else {
    $title = _("Add Client");
}

/* Set up the form object. */
$form = &Horde_Form::singleton('', $vars, $title);

/* Set up the form. */
$form->setButtons(_("Store"), true);
$form->addHidden('', 'client_id', 'int', false);
$form->addVariable(_("Client name"), 'client_name', 'text', true);

if ($form->validate($vars)) {
    $form->getInfo($vars, $info);
    $result = $clients->saveClient($info);
    if (is_a($result, 'PEAR_Error')) {
        $notification->push(sprintf(_("Could not save client. %s"), $result->message), 'horde.error');
    } else {
        $notification->push(_("Client saved."), 'horde.success');
        $url = Horde::applicationUrl('clients/index.php', true);
        header('Location: ' . $url);
        exit;
    }
}

/* Output the page. */
require MIDAS_TEMPLATES . '/common-header.inc';
require MIDAS_TEMPLATES . '/menu.inc';
$notification->notify(array('listeners' => 'status'));

/* Render the form. */
$renderer = &new Horde_Form_Renderer();
$form->renderActive($renderer, $vars, 'edit.php', 'post');

require $registry->get('templates', 'horde') . '/common-footer.inc';
