<?php
/**
 * The Midas script to delete campaigns.
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: midas/delete.php,v 1.16 2005/01/03 14:35:14 jan Exp $
 *
 * @author Marko Djukic <marko@oblo.com>
 * @version $Revision: 1.16 $
 * @package Midas
 */

@define('MIDAS_BASE', dirname(__FILE__));
require_once MIDAS_BASE . '/lib/base.php';
require_once 'Horde/Form.php';
require_once 'Horde/Form/Renderer.php';
require_once 'Horde/Variables.php';

/* Only admin should be using this. */
if (!Auth::isAdmin('midas:admin', PERMS_SHOW)) {
    $notification->push(_("You are not authorised for this action."), 'horde.warning');
    Horde::authenticationFailureRedirect();
}

/* Get some variables. */
$view = Util::getFormData('view');
$vars = &Variables::getDefaultVariables();
$campaign_id = $vars->get('campaign_id');
$form_submit = $vars->get('submitbutton');

/* Get campaign. */
$campaign = $campaigns->getCampaign($campaign_id);
if (is_a($campaign, 'PEAR_Error')) {
    $notification->push(sprintf(_("Can not delete campaign. %s"), $campaign->getMessage()), 'horde.error');
    $url = Horde::applicationUrl('campaigns.php', true);
    header('Location: ' . $url);
    exit;
}

/* Set up title. */
$title = sprintf(_("Delete Campaign '%s'"), $campaign['campaign_name']);

/* Set up the form object. */
$form = &Horde_Form::singleton('', $vars, $title);

/* Only read in the campaign vars when first loading up the form. */
if (!$form->isSubmitted()) {
    $vars = &new Variables($campaign);
}

/* Set up the form. */
$form->setButtons(array(_("Delete"), _("Do not delete")));
$form->addHidden('', 'campaign_id', 'int', false);
$form->addVariable(_("Do you really wish to delete this campaign?"), '', 'description', false);

if ($form_submit == _("Delete")) {
    if ($form->validate($vars)) {
        $form->getInfo($vars, $info);
        $delete = $campaigns->deleteCampaign($info['campaign_id']);
        if (is_a($delete, 'PEAR_Error')) {
            $notification->push(sprintf(_("Could not delete campaign. %s"), $delete->message), 'horde.error');
        } else {
            $notification->push(_("Campaign deleted."), 'horde.success');
            $url = Horde::applicationUrl('campaigns.php', true);
            header('Location: ' . $url);
            exit;
        }
    }
} elseif (!empty($form_submit)) {
    $notification->push(_("Campaign has not been deleted."), 'horde.message');
    $url = Horde::applicationUrl('campaigns.php', true);
    header('Location: ' . $url);
    exit;
}


/* Output the page. */
require MIDAS_TEMPLATES . '/common-header.inc';
require MIDAS_TEMPLATES . '/menu.inc';
$notification->notify(array('listeners' => 'status'));

/* Render the form. */
$renderer = &new Horde_Form_Renderer();
$form->renderActive($renderer, $vars, 'delete.php', 'post');

require $registry->get('templates', 'horde') . '/common-footer.inc';
