<?php
/**
 * The Midas script to edit campaigns.
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: midas/edit.php,v 1.29 2005/01/03 14:35:14 jan Exp $
 *
 * @author  Marko Djukic <marko@oblo.com>
 * @version $Revision: 1.29 $
 * @package Midas
 */

@define('MIDAS_BASE', dirname(__FILE__));
require_once MIDAS_BASE . '/lib/base.php';
require_once 'Horde/Form.php';
require_once 'Horde/Form/Action.php';
require_once 'Horde/Variables.php';

/* Only admin should be using this. */
if (!Auth::isAdmin('midas:admin', PERMS_SHOW)) {
    $notification->push(_("You are not authorised for this action."), 'horde.warning');
    Horde::authenticationFailureRedirect();
}

/* Get some variables. */
$vars = &Variables::getDefaultVariables();
$campaign_id = $vars->get('campaign_id');

/* Set up the form object. */
$form = &Horde_Form::singleton('', $vars, ($campaign_id ? _("Edit Campaign") : _("Add Campaign")));

/* Check if a campaign is being edited. */
if ($campaign_id && !$form->isSubmitted()) {
    $campaign = $campaigns->getCampaign($campaign_id);
    if ($campaign['campaign_type'] == 0) {
        $vfs_id = $campaign['campaign_ad'];
        $campaign['campaign_ad'] = array();
        $campaign['campaign_ad']['load']['file'] = $vfs_id;
        $campaign['campaign_ad']['load']['data'] = $vfs->read('.horde/midas', $vfs_id);
    }
    $vars = &new Variables($campaign);
}

/* Get the type of ad. */
$type = $vars->get('campaign_type');

/* Set up the form. */
$form->setButtons(_("Store"), true);
$form->addHidden('', 'campaign_id', 'int', false);
$form->addVariable(_("Client"), 'client_id', 'enum', true, false, null, array($clients->getClients(), true));
$form->addVariable(_("Campaign name"), 'campaign_name', 'text', true);
$form->addVariable(_("Number of showings"), 'campaign_quantity', 'int', true);
$form->addVariable(_("Link"), 'campaign_link', 'text', true);
$form->addVariable(_("Start date"), 'campaign_start', 'monthdayyear', true, false, null, array(null, date('Y') + 4));
$form->addVariable(_("End date"), 'campaign_end', 'monthdayyear', false, false, null, array(null, date('Y') + 4));
$form->addVariable(_("Keywords"), 'campaign_keywords', 'text', false, false, _("Comma separated list of keywords to be associated with this ad."));

/* Add ad type selection field with submit action. */
$v = &$form->addVariable(_("Ad type"), 'campaign_type', 'enum', true, false, null, array(Midas::getAdTypes(), true));
$v_action = &Horde_Form_Action::factory('submit');
$v->setAction($v_action);
$v->setOption('trackchange', true);
if (!is_null($vars->get('formname')) && $vars->get($v->getVarName()) != $vars->get('__old_' . $v->getVarName())) {
    $vars->set('campaign_ad', null);
}

/* Show the ad insertion variable according to type selected. */
switch ($type) {
case '0':
    $form->addVariable(_("Image"), 'campaign_ad', 'image', true);
    break;
case '1':
    $form->addVariable(_("Text"), 'campaign_ad', 'longtext', true, false, null, array('4', '40'));
    break;
}

if ($form->validate($vars)) {
    $form->getInfo($vars, $info);
    $campaign_id = $campaigns->saveCampaign($info);
    if (is_a($campaign_id, 'PEAR_Error')) {
        $notification->push(sprintf(_("Could not save campaign. %s"), $campaign_id->message), 'horde.error');
    } else {
        $notification->push(_("Campaign saved."), 'horde.success');
        $url = Util::addParameter(Horde::applicationUrl('view.php', true), 'campaign_id', $campaign_id);
        header('Location: ' . $url);
        exit;
    }
}

/* Output the page. */
require MIDAS_TEMPLATES . '/common-header.inc';
require MIDAS_TEMPLATES . '/menu.inc';
$notification->notify(array('listeners' => 'status'));

/* Render the form. */
require_once 'Horde/Form/Renderer.php';
$renderer = &new Horde_Form_Renderer();
$form->renderActive($renderer, $vars, 'edit.php', 'post', 'multipart/form-data');

require $registry->get('templates', 'horde') . '/common-footer.inc';
