<?php
/**
 * The Midas script to generate the HTML to display an ad in an external HTML
 * page.
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: midas/genhtml.php,v 1.19 2005/01/03 14:35:14 jan Exp $
 *
 * @author Marko Djukic <marko@oblo.com>
 * @version $Revision: 1.19 $
 * @package Midas
 */

@define('MIDAS_BASE', dirname(__FILE__));
require_once MIDAS_BASE . '/lib/base.php';
require_once 'Horde/Form.php';
require_once 'Horde/Form/Action.php';
require_once 'Horde/Form/Renderer.php';
require_once 'Horde/Variables.php';

/* Only admin should be using this. */
if (!Auth::isAdmin('midas:admin', PERMS_SHOW)) {
    $notification->push(_("You are not authorised for this action."), 'horde.warning');
    Horde::authenticationFailureRedirect();
}

/* Get some variables. */
$html = '';
$vars = &Variables::getDefaultVariables();
$campaign_id = $vars->get('campaign_id');
$select = $vars->get('select');
$type = $vars->get('type');

/* Set up the form. */
$form = &Horde_Form::singleton('', $vars, _("HTML Generation"));
$form->setButtons(_("Generate HTML"));

/* Campaign selection. */
$selection = array('random' => _("Any available randomly"), 'select' => _("One or more specific"));
$v = &$form->addVariable(_("Select which ads to display"), 'select', 'enum', true, false, null, array($selection, true));
$action = &Horde_Form_Action::factory('submit');
$v->setAction($action);
$v->setOption('trackchange', true);

switch ($select) {
case 'select':
    $campaign_list = $campaigns->getCampaignSelect('active');
    $form->addVariable(_("Select one or more available ads"), 'campaign_ids', 'multienum', true, false, null, array($campaign_list));
    $campaign_ids = $vars->get('campaign_ids');
    if (is_array($campaign_ids)) {
        $campaign_ids = implode('.', $campaign_ids);
    }
    $url_params['a'] = $campaign_ids;
    break;
}

/* Selection of embedding type. */
$embed_types = array('iframe' => _("Iframes"), 'javascript' => _("Javascript"), 'php_pear' => _("PHP using PEAR classes"));
$v = &$form->addVariable(_("Select how you wish to display the ad"), 'type', 'enum', true, false, null, array($embed_types, true));
$action = &Horde_Form_Action::factory('submit');
$v->setAction($action);
$v->setOption('trackchange', true);

switch ($type) {
case 'iframe':
    $form->addVariable(_("Name"), 'params[name]', 'text', true, false);
    $form->addVariable(_("Height"), 'params[height]', 'int', false, false);
    $form->addVariable(_("Width"), 'params[width]', 'int', false, false);
    break;

case 'javascript':
case 'php_pear':
    $form->setSubmitted(true);
    break;
}

/* Check if submitted and validate. */
if ($form->validate($vars)) {
    $form->getInfo($vars, $info);
    switch ($type) {
    case 'javascript':
        $url = Horde::applicationUrl('ad.php?d=js', true, -1);
        if (!empty($url_params)) {
            $url = Util::addParameter($url, $url_params);
        }
        $html[] = '&lt;script language="Javascript" src="'  . $url . '">&lt;/script>';
        break;

    case 'php_pear':
        $html[] = '&lt;?php $options[\'method\'] = \'POST\';';
        $html[] = '$params[\'url\'] = $_SERVER[\'SCRIPT_URI\'];';
        $html[] = '$params[\'embed\'] = \'php\';';
        $html[] = '$_POST[\'form_params\'] = $params;';
        $html[] = '$_POST[\'form_id\'] = ' . $info['form_id'] . ';';
        $html[] = 'require_once \'HTTP/Request.php\';';
        $html[] = '$http = &new HTTP_Request(\'' . Horde::applicationUrl('display.php', true, -1) . '\', $options);';
        $html[] = '$http->addRawPostData($_POST);';
        $html[] = '$http->sendRequest();';
        $html[] = 'if ($http->getResponseCode() != 200): echo \'Ad not available.\';';
        $html[] = 'else: echo $http->getResponseBody();';
        $html[] = 'endif; ?>';
        break;

    case 'iframe':
        $html[] = sprintf('&lt;iframe src="%s" name="%s" %s%s hspace="2" vspace="2" scrolling="auto" marginwidth=5 marginheight=5 frameborder="0">&lt;/iframe>',
                          Util::addParameter(Horde::applicationUrl('display.php', true, -1), 'form_id', $info['form_id']),
                          $info['params']['name'],
                          ($info['params']['width'] ? 'width="' . $info['params']['width'] . '" ' : ''),
                          ($info['params']['height'] ? 'height="' . $info['params']['height'] . '" ' : ''));
        break;
    }
}

/* Output the page. */
require MIDAS_TEMPLATES . '/common-header.inc';
require MIDAS_TEMPLATES . '/menu.inc';
$notification->notify(array('listeners' => 'status'));

/* Render the form. */
$renderer = &new Horde_Form_Renderer();
$form->renderActive($renderer, $vars, 'genhtml.php', 'post');

require MIDAS_TEMPLATES . '/genhtml/genhtml.inc';
require $registry->get('templates', 'horde') . '/common-footer.inc';
