<?php
/**
 * Midas storage implementation for PHP's PEAR database abstraction layer.
 *
 * The table structure can be created by the scripts/drivers/midas.sql script.
 * The needed tables are midas_clients and midas_campaigns.
 *
 * $Horde: midas/lib/Campaigns/sql.php,v 1.11 2004/10/08 15:45:24 chuck Exp $
 *
 * @author  Marko Djukic <marko@oblo.com>
 * @version $Revision: 1.11 $
 * @since   Midas 0.0.1
 * @package Midas
 */
class Midas_Campaigns_sql extends Midas_Campaigns {

    /**
     * Handle for the current database connection.
     * @var object DB $_db
     */
    var $_db;

    function Midas_Campaigns_sql($params)
    {
        parent::Midas_Campaigns($params);
        $this->initialise();
    }

    /**
     * Save a campaign details.
     *
     * @access private
     *
     * @return mixed  True on success, PEAR_Error on failure.
     */
    function _saveCampaign(&$info)
    {
        if (empty($info['campaign_id'])) {
            $info['campaign_id'] = $this->_db->nextId('midas_campaigns');
            if (is_a($info['campaign_id'], 'PEAR_Error')) {
                return $info['campaign_id'];
            }

            $sql_sprintf = 'INSERT INTO midas_campaigns (campaign_id, client_id, campaign_name, campaign_link, campaign_start, campaign_end, campaign_quantity, campaign_keywords, campaign_type, campaign_ad) VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s)';
        } else {
            $sql_sprintf = 'UPDATE midas_campaigns SET campaign_id = %s, client_id = %s, campaign_name = %s, campaign_link = %s, campaign_start = %s, campaign_end = %s, campaign_quantity = %s, campaign_keywords = %s, campaign_type = %s, campaign_ad = %s ' . sprintf('WHERE campaign_id = %s', (int)$info['campaign_id']);
        }

        $campaign_end = (empty($info['campaign_end'])) ? 'NULL' : $this->_db->quote($info['campaign_end']);
        $campaign_keywords = (empty($info['campaign_keywords'])) ? 'NULL' : $this->_db->quote($info['campaign_keywords']);

        /* Put together the sql statement. */
        $sql = sprintf($sql_sprintf,
                       (int)$info['campaign_id'],
                       (int)$info['client_id'],
                       $this->_db->quote($info['campaign_name']),
                       $this->_db->quote($info['campaign_link']),
                       $this->_db->quote($info['campaign_start']),
                       $campaign_end,
                       (int)$info['campaign_quantity'],
                       $campaign_keywords,
                       (int)$info['campaign_type'],
                       $this->_db->quote($info['campaign_ad']));
        Horde::logMessage('SQL Query by Midas_Campaigns_sql::_saveCampaign(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->query($sql);
        if (is_a($result, 'PEAR_Error')) {
            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
            return $result;
        }

        return $info['campaign_id'];
    }

    /**
     * Get a campaign.
     *
     * @access private
     *
     * @param integer $campaign_id  The campaign id to get.
     *
     * @return mixed  Campaign details or, PEAR_Error on failure.
     */
    function &_getCampaign($campaign_id)
    {
        /* Get the campaign. */
        $sql = sprintf('SELECT * FROM midas_campaigns WHERE campaign_id = %s',
                       (int)$campaign_id);
        Horde::logMessage('SQL Query by Midas_Campaigns_sql::_getCampaign(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->getRow($sql, DB_FETCHMODE_ASSOC);
        if (is_a($result, 'PEAR_Error')) {
            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
        } elseif (is_null($result)) {
            return PEAR::raiseError(_("Campaign not found."));
        }

        return $result;
    }

    /**
     * Delete a campaign.
     *
     * @access private
     *
     * @param integer $campaign_id  The campaign id to delete.
     *
     * @return mixed                True on success, PEAR_Error on failure.
     */
    function _deleteCampaign($campaign_id)
    {
        /* Delete main campaign details in the campaign table */
        $sql = sprintf('DELETE FROM midas_campaigns WHERE campaign_id = %s',
                       (int)$campaign_id);
        Horde::logMessage('SQL Query by Midas_Campaigns_sql::_deleteCampaign(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->query($sql);
        if (is_a($result, 'PEAR_Error')) {
            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
        }

        return $result;
    }

    /**
     * Get summary stats of campaigns.
     *
     * @access private
     *
     * @param optional string $filter  The type of filter to apply to the
     *                                 recordset.
     *
     * @return array  Array of rows and field values, PEAR_Error on failure.
     */
    function &_getCampaignStats($filter = '')
    {
        /* Fetch this driver's filter string. */
        $wsql = $this->_getFilter($filter);

        /* Get number of clients. */
        $sql = sprintf('SELECT DISTINCT client_id FROM midas_campaigns %s',
                       $wsql);
        Horde::logMessage('SQL Query by Midas_Campaigns_sql::_getCampaignsStats(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $query = $this->_db->query($sql);
        if (is_a($query, 'PEAR_Error')) {
            Horde::logMessage($query, __FILE__, __LINE__, PEAR_LOG_ERR);
            return $query;
        }

        $result['clients'] = $query->numRows();

        /* Get number of campaigns. */
        $sql = sprintf('SELECT COUNT(campaign_id) AS campaigns FROM midas_campaigns %s',
                       $wsql);
        Horde::logMessage('SQL Query by Midas_Campaigns_sql::_getCampaignsStats(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = array_merge($result, $this->_db->getRow($sql, DB_FETCHMODE_ASSOC));

        /* Get quantity, shows and clicks. */
        $sql = sprintf('SELECT SUM(campaign_quantity) AS quantity, SUM(campaign_showings) AS showings, SUM(campaign_clicks) AS clicks FROM midas_campaigns %s',
                       $wsql);
        Horde::logMessage('SQL Query by Midas_Campaigns_sql::_getCampaignsStats(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = array_merge($result, $this->_db->getRow($sql, DB_FETCHMODE_ASSOC));

        return $result;
    }

    /**
     * Get a list of campaigns.
     *
     * @access private
     *
     * @param optional string $filter  The type of filter to apply to the
     *                                 recordset.
     *
     * @return mixed  Array of rows and field values, PEAR_Error on failure.
     */
    function &_getCampaignList($filter = '')
    {
        $wsql = $this->_getFilter($filter);

        $sql = sprintf('SELECT * FROM midas_campaigns %s',
                       $wsql);
        Horde::logMessage('SQL Query by Midas_Campaigns_sql::_getCampaignList(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->getAll($sql, DB_FETCHMODE_ASSOC);

        return $result;
    }

    /**
     * Get a list of campaigns to be used in a select box.
     *
     * @access private
     *
     * @param optional string $filter  The type of filter to apply to the
     *                                 recordset.
     *
     * @return mixed  Array of rows and field values, PEAR_Error on failure.
     */
    function &_getCampaignSelect($filter = '')
    {
        $wsql = $this->_getFilter($filter);

        $sql = sprintf('SELECT campaign_id, campaign_name FROM midas_campaigns %s',
                       $wsql);
        Horde::logMessage('SQL Query by Midas_Campaigns_sql::_getCampaignSelect(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        return $this->_db->getAssoc($sql);
    }

    function &getClientCampaigns($client_id, $filter = '')
    {
        /* Fetch this driver's filter string. */
        $wsql = $this->_getFilter($filter);
        if (empty($wsql)) {
            $wsql = sprintf('WHERE client_id = %s', (int)$client_id);
        } else {
            $wsql .= sprintf(' AND client_id = %s', (int)$client_id);
        }

        $sql = sprintf('SELECT * FROM midas_campaigns %s',
                       $wsql);
        Horde::logMessage('SQL Query by Midas_Campaigns_sql::_getClientCampaigns(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->getAll($sql, DB_FETCHMODE_ASSOC);

        return $result;
    }

    function &numClientCampaigns($client_id, $filter = '')
    {
        /* Fetch this driver's filter string. */
        $wsql = $this->_getFilter($filter);
        if (empty($wsql)) {
            $wsql = sprintf('WHERE client_id = %s', (int)$client_id);
        } else {
            $wsql .= sprintf(' AND client_id = %s', (int)$client_id);
        }

        $sql = sprintf('SELECT COUNT(campaign_id) FROM midas_campaigns %s',
                       $wsql);
        Horde::logMessage('SQL Query by Midas_Campaigns_sql::_numClientCampaigns(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->getOne($sql);

        return $result;
    }

    /**
     * Translate the filter requested into the driver's filter statement.
     *
     * @access private
     *
     * @param string $filter  The type of filter to apply to the recordset.
     *
     * @return string  Filter statement used by this driver.
     */
    function _getFilter($filter)
    {
        switch ($filter) {
        case 'active':
            /* Return only campaigns currently running. */
            require_once 'Date/Calc.php';
            $wsql = sprintf('WHERE %1$s.campaign_start <= %2$s AND (%1$s.campaign_end > %2$s OR %1$s.campaign_end IS NULL) AND (%1$s.campaign_showings < %1$s.campaign_quantity OR %1$s.campaign_quantity = 0)',
                           $this->_params['table_campaigns'],
                           $this->_db->quote(Date_Calc::dateNow('%Y-%m-%d')));
            break;

        case 'new':
            /* Return only upcoming campaigns. */
            require_once 'Date/Calc.php';
            $wsql = sprintf('WHERE %s.campaign_start > %s',
                           $this->_params['table_campaigns'],
                           $this->_db->quote(Date_Calc::dateNow('%Y-%m-%d')));
            break;

        case 'old':
            /* Return only finished campaigns. */
            require_once 'Date/Calc.php';
            $wsql = sprintf('WHERE %1$s.campaign_end <= %2$s OR (%1$s.campaign_showings >= %1$s.campaign_quantity AND %1$s.campaign_quantity > 0)',
                           $this->_params['table_campaigns'],
                           $this->_db->quote(Date_Calc::dateNow('%Y-%m-%d')));
            break;

        default:
            /* Return all campaigns. */
            $wsql = '';
        }

        return $wsql;
    }

    /**
     * Get an array of all the available keywords.
     *
     * @access public
     *
     * @param int  $show  What is going to be displayed.
     *
     * @return array  Array of rows and field values, PEAR_Error on failure.
     */
    function getKeywords($show)
    {
        $wsql = $this->_getFilter($show);

        $sql = sprintf('SELECT campaign_keywords FROM %s %s',
                       $this->_params['table_campaigns'],
                       $wsql);
        Horde::logMessage('SQL Query by Midas_Campaigns_sql::getKeywords(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->getCol($sql);

        $keywords = array();
        foreach ($result as $r) {
            if (!empty($r)) {
                $keywords = array_unique(array_merge($keywords, explode(',', $r)));
            }
        }

        return $keywords;

    }

    function getImageVfsId($ad_id = null)
    {
        $tbl_campaigns = $this->_params['table_campaigns'];

        if (!empty($ad_id)) {
            $sql = sprintf('SELECT campaign_ad FROM %s WHERE campaign_id = %s',
                           $tbl_campaigns, $ad_id);
        }
        Horde::logMessage('SQL Query by Midas_Campaigns_sql::getImageVfsId(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->getOne($sql);
        if (is_a($result, 'PEAR_Error')) {
            return $result;
        }

        return $result;
    }

    /**
     * Close a campaign.
     *
     * @param integer $campaign_id  The campaign id to close.
     *
     * @return mixed                True on success, PEAR_Error on failure.
     */
    function closeCampaign($campaign_id)
    {
        /* Delete main campaign details in the campaign table */
        $sql = sprintf('UPDATE %s SET campaign_end = %s WHERE campaign_id = %s',
                       $this->_params['table_campaigns'],
                       $this->_db->quote(Date_Calc::dateNow('%Y-%m-%d')),
                       (int)$campaign_id);
        Horde::logMessage('SQL Query by Midas_Campaigns_sql::closeCampaign(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->query($sql);

        if (DB::isError($result)) {
            return PEAR::raiseError(sprintf(_("Campaign could not be closed. %s"), $result->message));
        }

        return true;
    }

    function updateCounter($ad_id = null, $type = '')
    {
        if (is_null($ad_id) && empty($type)) {
            return false;
        }

        $tbl_campaigns = $this->_params['table_campaigns'];

        switch ($type) {
        case 'show':
            $sql = sprintf('UPDATE %s SET campaign_showings = campaign_showings + 1 WHERE campaign_id = %s',
                           $tbl_campaigns, $ad_id);
            break;

        case 'click':
            $sql = sprintf('UPDATE %s SET campaign_clicks = campaign_clicks + 1 WHERE campaign_id = %s',
                           $tbl_campaigns, $ad_id);
            break;
        }

        Horde::logMessage('SQL Query by Midas_Campaigns_sql::updateCounter(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->query($sql);
        if (is_a($result, 'PEAR_Error')) {
            return $result;
        }
        return true;
    }

    /**
     * Get the form data from the manage form and return an array.
     *
     * @access public
     *
     * @return array  An array of the values passed by the form.
     */
    function _getFormData()
    {
        $in['client_name'] = Util::getFormData('client_name');
        $in['client_id'] = Util::getFormData('client_id');
        $in['campaign_name'] = Util::getFormData('campaign_name');
        $in['campaign_link'] = Util::getFormData('campaign_link');
        $in['campaign_quantity'] = Util::getFormData('campaign_quantity');
        $in['start_year'] = Util::getFormData('start_year');
        $in['start_month'] = Util::getFormData('start_month');
        $in['start_day'] = Util::getFormData('start_day');
        $in['end_year'] = Util::getFormData('end_year');
        $in['end_month'] = Util::getFormData('end_month');
        $in['end_day'] = Util::getFormData('end_day');
        $in['campaign_keywords'] = Util::getFormData('campaign_keywords');

        return $in;
    }

    function initialise()
    {
        global $registry;

        Horde::assertDriverConfig($this->_params, 'storage',
            array('phptype', 'hostspec', 'username', 'database'));

        if (empty($this->_params['table_campaigns'])) {
            $this->_params['table_campaigns'] = 'midas_campaigns';
        }

        if (empty($this->_params['table_clients'])) {
            $this->_params['table_clients'] = 'midas_clients';
        }

        /* Connect to the SQL server using the supplied parameters. */
        require_once 'DB.php';
        $this->_db = &DB::connect($this->_params,
                                  array('persistent' => !empty($this->_params['persistent'])));
        if (is_a($this->_db, 'PEAR_Error')) {
            Horde::fatal($this->_db, __FILE__, __LINE__);
        }

        $this->_db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS);

        return true;
    }

}
