<?php
/**
 * Midas storage implementation for PHP's PEAR database abstraction layer.
 *
 * The table structure can be created by the scripts/drivers/midas.sql script.
 * The needed tables are midas_clients and midas_campaigns.
 *
 * $Horde: midas/lib/Clients/sql.php,v 1.7 2004/10/08 15:45:24 chuck Exp $
 *
 * @author  Marko Djukic <marko@oblo.com>
 * @version $Revision: 1.7 $
 * @since   Midas 0.0.1
 * @package Midas
 */
class Midas_Clients_sql extends Midas_Clients {

    /** Handle for the current database connection.
        @var object DB $db */
    var $_db;

    function Midas_Clients_sql($params)
    {
        parent::Midas_Clients($params);
        $this->initialise();
    }

    /**
     * Save a campaign details.
     *
     * @access private
     *
     * @return mixed  True on success, PEAR_Error on failure.
     */
    function _saveClient(&$info)
    {
        if (empty($info['client_id'])) {
            $info['client_id'] = $this->_db->nextId('midas_clients');
            if (is_a($info['client_id'], 'PEAR_Error')) {
                return $info['client_id'];
            }

            $sql_sprintf = 'INSERT INTO midas_clients (client_id, client_name) VALUES (%s, %s)';
        } else {
            $sql_sprintf = 'UPDATE midas_clients SET client_id = %s, client_name = %s ' . sprintf('WHERE client_id = %s', (int)$info['client_id']);
        }

        /* Put together the sql statement. */
        $sql = sprintf($sql_sprintf,
                       (int)$info['client_id'],
                       $this->_db->quote($info['client_name']));
        Horde::logMessage('SQL Query by Midas_Clients_sql::_saveClient(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->query($sql);
        if (is_a($result, 'PEAR_Error')) {
            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
            return $result;
        }

        return $info['client_id'];
    }

    /**
     * Get a client.
     *
     * @access private
     *
     * @param integer $client_id  The client id to get.
     *
     * @return mixed  Client details or PEAR_Error on failure.
     */
    function &_getClient($client_id)
    {
        /* Get the client. */
        $sql = sprintf('SELECT * FROM midas_clients WHERE client_id = %s',
                       (int)$client_id);
        Horde::logMessage('SQL Query by Midas_Clients_sql::_getClient(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        return $this->_db->getRow($sql, DB_FETCHMODE_ASSOC);
    }

    /**
     * Get a list of clients.
     *
     * @access private
     *
     * @param integer $client_id  The client id to get.
     *
     * @return mixed  Client details or, PEAR_Error on failure.
     */
    function &_getClients($one_col = true)
    {
        /* Get the client. */
        $sql = 'SELECT * FROM midas_clients';
        Horde::logMessage('SQL Query by Midas_Clients_sql::_getClients(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        if ($one_col) {
            $clients = $this->_db->getAssoc($sql);
        } else {
            $clients = $this->_db->getAll($sql, DB_FETCHMODE_ASSOC);
        }

        if (is_a($clients, 'PEAR_Error')) {
            Horde::logMessage($clients, __FILE__, __LINE__, PEAR_LOG_ERR);
        }

        return $clients;
    }

    /**
     * Delete a client.
     *
     * @access private
     *
     * @param integer $client_id  The client id to delete.
     *
     * @return mixed                True on success, PEAR_Error on failure.
     */
    function _deleteClient($client_id)
    {
        /* Delete main client details in the client table */
        $sql = sprintf('DELETE FROM midas_clients WHERE client_id = %s',
                       (int)$client_id);
        Horde::logMessage('SQL Query by Midas_Clients_sql::_deleteClient(): ' . $sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->query($sql);
        if (is_a($result, 'PEAR_Error')) {
            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
        }

        return $result;
    }

    /**
     * Get summary stats of clients.
     *
     * @access public
     *
     * @param int  $limit  The number of records to limit the query.
     *
     * @param int  $start  The start record.
     *
     * @return array  Array of rows and field values, PEAR_Error on failure.
     */
    function getClientStats($where = null, $limit = NULL, $start = NULL)
    {
        $wsql = $this->_getWhereFilter($where);

        $sql = sprintf('SELECT sum(campaign_quantity) AS quantity, sum(campaign_showings) AS showings, sum(campaign_clicks) AS clicks FROM %s %s',
                       $this->_params['table_campaigns'],
                       $wsql);
        Horde::logMessage($sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->getRow($sql, DB_FETCHMODE_ASSOC);

        $sql = sprintf('SELECT DISTINCT count(client_id) AS clients FROM %s %s',
                       $this->_params['table_campaigns'],
                       $wsql);
        Horde::logMessage($sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = array_merge($result, $this->_db->getRow($sql, DB_FETCHMODE_ASSOC));

        $sql = sprintf('SELECT DISTINCT count(campaign_id) AS campaigns FROM %s %s',
                       $this->_params['table_campaigns'],
                       $wsql);
        Horde::logMessage($sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = array_merge($result, $this->_db->getRow($sql, DB_FETCHMODE_ASSOC));
        return ($result);
    }

    /**
     * Get an array of all the available keywords.
     *
     * @access public
     *
     * @param int  $show  What is going to be displayed.
     *
     * @return array  Array of rows and field values, PEAR_Error on failure.
     */
    function getKeywords($show)
    {
        $wsql = $this->_getWhereFilter($show);

        $sql = sprintf('SELECT campaign_keywords FROM %1$s %2$s',
                       $this->_params['table_campaigns'],
                       $wsql);

        Horde::logMessage($sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->getCol($sql);

        $keywords = array();
        foreach ($result as $r) {
            if (!empty($r)) {
                $keywords = array_unique(array_merge($keywords, explode(' ', $r)));
            }
        }

        return $keywords;
    }

    function _getWhereFilter($show)
    {
        switch ($show) {
        case MIDAS_FILTER_ACTIVE:
            $wsql = sprintf('WHERE %1$s.campaign_start <= %2$s AND (%1$s.campaign_end > %2$s OR %1$s.campaign_end IS NULL) AND (%1$s.campaign_showings < %1$s.campaign_quantity OR %1$s.campaign_quantity = 0)',
                           $this->_params['table_campaigns'],
                           $this->_db->quote(Date_Calc::dateNow('%Y-%m-%d')));
            break;

        case MIDAS_FILTER_NEW:
            $wsql = sprintf('WHERE %s.campaign_start > %s',
                           $this->_params['table_campaigns'],
                           $this->_db->quote(Date_Calc::dateNow('%Y-%m-%d')));
            break;

        case MIDAS_FILTER_OLD:
            $wsql = sprintf('WHERE %1$s.campaign_end <= %2$s OR (%1$s.campaign_showings >= %1$s.campaign_quantity AND %1$s.campaign_quantity > 0)',
                           $this->_params['table_campaigns'],
                           $this->_db->quote(Date_Calc::dateNow('%Y-%m-%d')));
            break;

        default:
            $wsql = '';
        }

        return $wsql;
    }

    function getImageVfsId($ad_id = null)
    {
        $tbl_campaigns = $this->_params['table_campaigns'];

        if (!empty($ad_id)) {
            $sql = sprintf('SELECT campaign_image FROM %s WHERE campaign_id = %s',
                           $tbl_campaigns, $ad_id);
        }

        Horde::logMessage($sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->getOne($sql);
        if (is_a($result, 'PEAR_Error')) {
            return $result;
        }

        return $result;
    }

    /**
     * Close a campaign.
     *
     * @param integer $campaign_id  The campaign id to close.
     *
     * @return mixed                True on success, PEAR_Error on failure.
     */
    function closeClient($campaign_id)
    {
        /* Delete main campaign details in the campaign table */
        $sql = sprintf('UPDATE %s SET campaign_end = %s WHERE campaign_id = %s',
                       $this->_params['table_campaigns'],
                       $this->_db->quote(Date_Calc::dateNow('%Y-%m-%d')),
                       (int)$campaign_id);
        Horde::logMessage($sql, __FILE__, __LINE__, PEAR_LOG_DEBUG);
        $result = $this->_db->query($sql);

        if (DB::isError($result)) {
            return PEAR::raiseError(sprintf(_("Client could not be closed. %s"), $result->message));
        }

        return true;
    }

    /**
     * Get the form data from the manage form and return an array.
     *
     * @access public
     *
     * @return array  An array of the values passed by the form.
     */
    function _getFormData()
    {
        $in['client_name'] = Util::getFormData('client_name');
        $in['client_id'] = Util::getFormData('client_id');
        $in['campaign_name'] = Util::getFormData('campaign_name');
        $in['campaign_link'] = Util::getFormData('campaign_link');
        $in['campaign_quantity'] = Util::getFormData('campaign_quantity');
        $in['start_year'] = Util::getFormData('start_year');
        $in['start_month'] = Util::getFormData('start_month');
        $in['start_day'] = Util::getFormData('start_day');
        $in['end_year'] = Util::getFormData('end_year');
        $in['end_month'] = Util::getFormData('end_month');
        $in['end_day'] = Util::getFormData('end_day');
        $in['campaign_keywords'] = Util::getFormData('campaign_keywords');

        return $in;
    }

    function initialise()
    {
        global $registry;

        Horde::assertDriverConfig($this->_params, 'storage',
            array('phptype', 'hostspec', 'username', 'database'));

        /* Connect to the SQL server using the supplied parameters. */
        require_once 'DB.php';
        $this->_db = &DB::connect($this->_params,
                                  array('persistent' => !empty($this->_params['persistent'])));
        if (is_a($this->_db, 'PEAR_Error')) {
            Horde::fatal($this->_db, __FILE__, __LINE__);
        }

        $this->_db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS);

        return true;
    }

}
