<?php
/**
 * Midas_Display:: class.
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: midas/lib/Display.php,v 1.5 2005/01/03 14:35:15 jan Exp $
 *
 * @author  Marko Djukic <marko@oblo.com>
 * @version $Revision: 1.5 $
 * @package Midas
 */
class Midas_Display {

    function Midas_Display($params)
    {
        $this->_params = $params;
    }

    /**
     * Attempts to return a concrete Midas_Display instance based on $driver.
     *
     * @param string $driver          The type of concrete Midas_Display
     *                                subclass to return. This based on the
     *                                display driver ($driver). The code is
     *                                dynamically included.
     *
     * @param optional array $params  A hash containing any additional
     *                                configuration or connection parameters a
     *                                subclass might need.
     *
     * @return mixed  The created concrete Midas_Display instance, or false
     *                on error.
     */
    function &factory($driver, $params = array())
    {
        $driver = String::lower(basename($driver));
        include_once dirname(__FILE__) . '/Display/' . $driver . '.php';
        $class = 'Midas_Display_' . $driver;
        if (class_exists($class)) {
            return $ret = &new $class($params);
        } else {
            Horde::fatal(PEAR::raiseError(sprintf(_("No such display driver '%s' found"), $driver)), __FILE__, __LINE__);
        }
    }

    /**
     * Attempts to return a reference to a concrete Midas_Display instance
     * based on $driver. It wil only create a new instance if no Midas_Display
     * instance with the same parameters currently exists.
     *
     * This method must be invoked as: $var = &Midas_Display::singleton()
     *
     * @param string $driver          The type of concrete Midas_Display
     *                                subclass to return. This based on the
     *                                display driver ($driver). The code is
     *                                dynamically included.
     *
     * @param optional array $params  A hash containing any additional
     *                                configuration or connection parameters a
     *                                subclass might need.
     *
     * @return mixed  The created concrete Midas_Display instance, or false
     *                on error.
     */
    function &singleton($driver, $params = array())
    {
        static $instances;

        if (!isset($instances)) {
            $instances = array();
        }

        $signature = serialize(array($driver, $params));
        if (!isset($instances[$signature])) {
            $instances[$signature] = &Midas_Display::factory($driver, $params);
        }

        return $instances[$signature];
    }

}
