<?php
/**
 * The Midas script to view a campaign.
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file COPYING for license information (GPL). If you did not
 * receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * $Horde: midas/view.php,v 1.14 2005/01/03 14:35:14 jan Exp $
 *
 * @author Marko Djukic <marko@oblo.com>
 * @version $Revision: 1.14 $
 * @package Midas
 */

@define('MIDAS_BASE', dirname(__FILE__));
require_once MIDAS_BASE . '/lib/base.php';
require_once 'Horde/Form.php';
require_once 'Horde/Form/Renderer.php';
require_once 'Horde/Variables.php';

/* Only admin should be using this. */
if (!Auth::isAdmin('midas:admin', PERMS_SHOW)) {
    $notification->push(_("You are not authorised for this action."), 'horde.warning');
    Horde::authenticationFailureRedirect();
}

/* Get some variables. */
$vars = &Variables::getDefaultVariables();
$campaign_id = $vars->get('campaign_id');

/* Check if a campaign is being edited. */
$campaign = $campaigns->getCampaign($campaign_id);
if (is_a($campaign, 'PEAR_Error')) {
    $notification->push(sprintf(_("Can not view campaign. %s"), $campaign->getMessage()), 'horde.error');
    $url = Horde::applicationUrl('campaigns.php', true);
    header('Location: ' . $url);
    exit;
}

/* Set up the vars. */
$vars = &new Variables($campaign);

/* Get the type of ad. */
$type = $vars->get('campaign_type');

/* Set up the form object. */
$form = &Horde_Form::singleton('', $vars, _("Campaign Details"));

/* Set up the form. */
$form->setButtons(_("Store"), true);
$form->addHidden('', 'campaign_id', 'int', false);
$form->addVariable(_("Client"), 'client_id', 'enum', true, false, null, array($clients->getClients(), true));
$form->addVariable(_("Campaign name"), 'campaign_name', 'text', true);
$form->addVariable(_("Number of showings"), 'campaign_quantity', 'int', true);
$form->addVariable(_("Link"), 'campaign_link', 'text', true);
$form->addVariable(_("Start date"), 'campaign_start', 'monthdayyear', true, false, null, array(null, date('Y') + 4));
$form->addVariable(_("End date"), 'campaign_end', 'monthdayyear', false, false, null, array(null, date('Y') + 4));
$form->addVariable(_("Keywords"), 'campaign_keywords', 'text', false);
$form->addVariable(_("Showings"), 'campaign_showings', 'text', false, true);
$form->addVariable(_("Clicks"), 'campaign_clicks', 'text', false, true);
$form->addVariable(_("Ad type"), 'campaign_type', 'enum', true, false, null, array(Midas::getAdTypes(), true));

/* Show the ad insertion variable according to type selected. */
switch ($type) {
case '0':
    $form->addVariable(_("Image"), 'campaign_ad', 'image', true);

    /* Set up the image array. */
    $img = Midas::getImageArray($vars->get('campaign_ad'));
    $vars->set('campaign_ad', $img);
    break;

case '1':
    $form->addVariable(_("Text"), 'campaign_ad', 'longtext', true, false, null, array('4', '40'));
    break;
}

/* Output the page. */
require MIDAS_TEMPLATES . '/common-header.inc';
require MIDAS_TEMPLATES . '/menu.inc';
$notification->notify(array('listeners' => 'status'));

/* Render the form. */
$renderer = &new Horde_Form_Renderer();
$form->renderInactive($renderer, $vars, 'edit.php');

require $registry->get('templates', 'horde') . '/common-footer.inc';
